netapp_ontap.models.firmware_history_update_state_worker API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_history_update_state_worker`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareHistoryUpdateStateWorkerSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareHistoryUpdateStateWorker object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `error GET POST PATCH`

    The error field of the firmware_history_update_state_worker.

  `node GET POST PATCH`

    The node field of the firmware_history_update_state_worker.

  `state GET POST PATCH`

    The state of each worker that a node is controlling.

    Valid choices:

    - idle
    - working
    - complete
    - failed
    - waiting_to_retry